yakumo.patch

Package yakumo :: Module patch |
[hide private]
[frames] | no frames]

# Module patch

source code

Functions | [hide private]
get_session_endpoint(self, service_key) Return the endpoint from config or the catalog. | source code

Variables | [hide private]
| __package__ = `None`

Function Details | [hide private]

### get_session_endpoint(self, service_key) | source code
    Return the endpoint from config or the catalog.

    THIS IS FROM os_client_config.CloudConfig.get_session_endpoint()
    If a configuration lists an explicit endpoint for a service,
    return that. Otherwise, fetch the service catalog from the
    keystone session and return the appropriate endpoint.

    :param service_key: Generic key for service, such as 'compute' or
                        'network'

    :returns: Endpoint for the service, or None if not found